========
Examples
========

Below are some examples of the Abaqus/Python scripts.

How to add a new example
------------------------

To add a new example, add the script to the examples directory and add docstring to the top of the script. The docstring should contain the following information:

* A title for the example
* A description of the example

See the examples in the examples directory for examples of docstrings.
